/*
  ECCX08 Random Number

  This sketch uses the ECC508 or ECC608 to generate a random number 
  every second and print it to the Serial monitor

  Circuit:
   - MKR board with ECC508 or ECC608 on board

  created 19 July 2018
  by Sandeep Mistry
*/

#include <ArduinoECCX08.h>
#include <Wire.h>
#include "ECCX08.h"


byte mydata[128];
byte old_config[128] = {1,35,6,127,0,0,80,0,16,224,99,143,238,192,69,0,192,0,85,0,131,32,135,32,143,32,196,143,143,143,143,104,159,143,175,143,0,0,0,0,0,0,0,0,0,0,0,0,0,0,175,143,255,255,255,255,0,0,0,0,255,255,255,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,85,85,255,255,0,0,0,0,0,57,51,0,51,0,51,0,28,0,28,0,28,0,28,0,28,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,28,0};

void setup() {
  Serial.begin(9600);
  while (!Serial);

  for(int i = 0; i < 128; i++)
  {
    int j=i;
    if (j>=250){
      j=j-250;
    }
    mydata[i]=j;
  }

  Serial.println("ready");
  delay(100);
  int didRun=0;
  didRun = ECCX08.readConfiguration(mydata);

  Serial.println("Showing config as HEX:index");
  for(int i = 0; i < 128; i++)
  {
    char my_data[2];

    sprintf(my_data,"%02X",mydata[i]);
    Serial.print(my_data);
    
    //Serial.print(mydata[i], HEX);
    Serial.print(":");
    Serial.print(i);
    Serial.print(", ");
  }
  Serial.println();

  if(didRun){
    Serial.println("readConfiguration returned true");
  } else {
    Serial.println("There was a problem, readConfiguration returned false");
  }

  //Output char array
  Serial.print("{");
  for(int i = 0; i < 128; i++)
  { Serial.print(mydata[i]);
    if (i!=127){
      Serial.print(",");
    }
  }
   Serial.println("}");
  
  if (!ECCX08.begin()) {
    Serial.println("Failed to communicate with ECC508/ECC608!");
    while (1);
  }

  Serial.print("Did run result: ");
  Serial.println(didRun);

  //Attempt to write config
  didRun=0;
  didRun = ECCX08.writeConfiguration(old_config);

  if(didRun){
    Serial.println("writeConfiguration returned true");
  } else {
    Serial.println("There was a problem, writeConfiguration returned false");
  }
  Serial.println("done");

  if (!ECCX08.locked()) {
    Serial.println("The ECC508/ECC608 is not locked!");
    while (1);
  }
}

void loop() {
  Serial.print("Setting up version");
 // Serial.println(ECCX08.version());

  delay(1000);
}
